#!/usr/bin/env python
# encoding: utf-8
"""
create_simple-catalogue_xml.py

Created by Theresa Velden on 2012-07-23.
Copyright (c) 2012 Cornell University. All rights reserved.
"""

import sys
import os
import datetime

from lxml import etree

try:
    import xml.etree.cElementTree as ET
except ImportError:
    import xml.etree.ElementTree as ET


#### GLOBAL VARIABLES ##################

movieDataFile="../data/movies.csv"
actorDataFile="../data/actors.csv"
matchingDataFile="../data/movie_actors.csv"
root = etree.Element("catalogue")

#### FUNCTIONS #########################

def createMovieDictionary(data_file):
	"""reads a csv file with movie data and creates a dictionary"""
	f = open(data_file,"r")
	rawData = f.readlines()
	f.close()
	movies={}
	m=0
	for line in rawData:
		if m==0: # do not process the header line of csv file
			m+=1
		else:
			data = line.split("| |")
			title=data[1]
			movieID=data[0].replace("|","")
			if title!="":
				movies[movieID]=title.decode("utf-8")
	return movies

	
def createActorDictionary(data_file):
	"""reads a csv file with actor data and creates a dictionary """
	f = open(data_file,"r")
	rawData = f.readlines()
	f.close()
	actors={}
	m=0
	for line in rawData:
		if m==0: # do not process the header line of csv file
			m+=1
		else:
			data = line.split("| |")
			name=data[1]
			actorID=data[0].replace("|","")
			if name!="":
				actors[actorID]=name.decode("utf-8")
	return actors

	
def createConversionTable(data_file):
	"""reads a csv file linking movie IDs with actor IDs"""
	f = open(data_file,"r")
	rawData = f.readlines()
	f.close()
	table={}
	m=0
	for line in rawData:
		if m==0: # do not process the header line of csv file
			m+=1
		else:
			data = line.split("| |")
			actorID=data[1].replace("|\r\n","")
			movieID=data[0].replace("|","")
			if movieID not in table:
				value=[]
				value.append(actorID)
				table[movieID]=value
			else:
				table[movieID].append(actorID)
	return table


def createXML(allMovies,allActors,table,root):
	for movieID, movieTitle in allMovies.iteritems():
		if (movieID in table and len(table[movieID]) > 0): # require movie to have some actor information
			movie=etree.SubElement(root, "movie")
			etree.SubElement(movie, "title").text = movieTitle
			actors=etree.SubElement(movie, "actors")
			for item in table[movieID]:
				if item in allActors:
					actor=etree.SubElement(actors, "actor")
					etree.SubElement(actor, "name").text = allActors[item]
				else:
					print item, ": this actor is not in list of actors"
		else:
			print movieID, ": this movie has no actor information"
	return root


def writeXML(root):
	f = open("../docs/simple-catalogue.xml","w")
	f.write('<?xml version="1.0" encoding="UTF-8" ?>\r\n\r\n')
	now = datetime.datetime.now()
	header="<!-- catalogue_simple.xml  Created: "+ now.strftime("%Y-%m-%d %H:%M") + " -->\r\n\r\n"
	f.write(header)
	f.write(etree.tostring(root, pretty_print=True))
	f.close()

###### read data from csv files and create xml document ############

allMovies = createMovieDictionary(movieDataFile)
allActors = createActorDictionary(actorDataFile)
table = createConversionTable(matchingDataFile)

root = createXML(allMovies,allActors,table,root)

if __name__ == "__main__":
    writeXML(root)



